==> aliyun-sdk-datahub-2.19.0-public-sources.jar: com/aliyun/datahub/client/model/SubscriptionEntry.java <==
package com.aliyun.datahub.client.model;

import com.fasterxml.jackson.annotation.JsonProperty;

public class SubscriptionEntry extends BaseResult {
    @JsonProperty("SubId")
    private String subId;
    @JsonProperty("Creator")
    private String creator;
    @JsonProperty("Comment")
    private String comment;
    @JsonProperty("Type")
    private SubscriptionType type;
    @JsonProperty("State")
    private SubscriptionState state;
    @JsonProperty("CreateTime")
    private long createTime;
    @JsonProperty("LastModifyTime")
    private long lastModifyTime;
    @JsonProperty("RouterPriority")
    private SubscriptionRouterPriority routerPriority;

    public String getSubId() {
        return subId;
    }

    public void setSubId(String subId) {
        this.subId = subId;
    }

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public String getComment() {
        return comment;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

    public SubscriptionType getType() {
        return type;
    }

    public void setType(SubscriptionType type) {
        this.type = type;
    }

    public SubscriptionState getState() {
        return state;
    }

    public void setState(SubscriptionState state) {
        this.state = state;
    }

    public long getCreateTime() {
        return createTime;
    }

    public void setCreateTime(long createTime) {
        this.createTime = createTime;
    }

    public long getLastModifyTime() {
        return lastModifyTime;
    }

    public void setLastModifyTime(long lastModifyTime) {
        this.lastModifyTime = lastModifyTime;
    }

    public SubscriptionRouterPriority getRouterPriority() {
        return routerPriority;
    }

    public void setRouterPriority(SubscriptionRouterPriority routerPriority) {
        this.routerPriority = routerPriority;
    }
}

==> aliyun-sdk-datahub-2.21.6-public-sources.jar: com/aliyun/datahub/client/model/SubscriptionEntry.java <==
package com.aliyun.datahub.client.model;

import com.fasterxml.jackson.annotation.JsonProperty;

public class SubscriptionEntry extends BaseResult {
    @JsonProperty("TopicName")
    private String topicName;
    @JsonProperty("SubId")
    private String subId;
    @JsonProperty("Creator")
    private String creator;
    @JsonProperty("Comment")
    private String comment;
    @JsonProperty("Type")
    private SubscriptionType type;
    @JsonProperty("State")
    private SubscriptionState state;
    @JsonProperty("CreateTime")
    private long createTime;
    @JsonProperty("LastModifyTime")
    private long lastModifyTime;
    @JsonProperty("RouterPriority")
    private SubscriptionRouterPriority routerPriority;

    public String getTopicName() {
        return topicName;
    }

    public void setTopicName(String topicName) {
        this.topicName = topicName;
    }

    public String getSubId() {
        return subId;
    }

    public void setSubId(String subId) {
        this.subId = subId;
    }

    public String getCreator() {
        return creator;
    }

    public void setCreator(String creator) {
        this.creator = creator;
    }

    public String getComment() {
        return comment;
    }

    public void setComment(String comment) {
        this.comment = comment;
    }

    public SubscriptionType getType() {
        return type;
    }

    public void setType(SubscriptionType type) {
        this.type = type;
    }

    public SubscriptionState getState() {
        return state;
    }

    public void setState(SubscriptionState state) {
        this.state = state;
    }

    public long getCreateTime() {
        return createTime;
    }

    public void setCreateTime(long createTime) {
        this.createTime = createTime;
    }

    public long getLastModifyTime() {
        return lastModifyTime;
    }

    public void setLastModifyTime(long lastModifyTime) {
        this.lastModifyTime = lastModifyTime;
    }

    public SubscriptionRouterPriority getRouterPriority() {
        return routerPriority;
    }

    public void setRouterPriority(SubscriptionRouterPriority routerPriority) {
        this.routerPriority = routerPriority;
    }
}
